"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const ramda_1 = require("ramda");
const content_types_1 = require("@ewizardjs/content-types");
async function default_1(systemSettings, baseDir, { fileProps, filePathProps, componentsPackageName }) {
    const contentType = ramda_1.pathOr('', ['content', 'type'], systemSettings);
    const blocksDir = ramda_1.pathOr('', ['path', 'blocks'], systemSettings);
    const localBlocksDir = ramda_1.pathOr('', ['path', 'localBlocks'], systemSettings);
    const rootComponentPath = ramda_1.pathOr('', ['path', 'rootComponent'], systemSettings);
    const rootComponentLoaderConfig = {
        test: new RegExp(rootComponentPath),
        use: [
            {
                loader: 'template-loader',
                options: {
                    baseDir,
                    fileProps,
                    filePathProps,
                    componentsPackageName,
                    componentType: 'root',
                    id: 'app',
                },
            },
        ],
    };
    switch (contentType) {
        case content_types_1.ContentTypes.EMAIL:
        case content_types_1.ContentTypes.SITE:
        case content_types_1.ContentTypes.MODULE:
        case content_types_1.ContentTypes.MESSENGER_AD:
            return [
                {
                    test: /index\.vue$/,
                    include: [path_1.resolve(baseDir, blocksDir), path_1.resolve(baseDir, localBlocksDir)],
                    use: [
                        {
                            loader: 'template-loader',
                            options: {
                                baseDir,
                                filePathProps,
                                componentsPackageName,
                                componentType: 'block',
                                paths: [path_1.resolve(baseDir, blocksDir), path_1.resolve(baseDir, localBlocksDir)],
                            },
                        },
                    ],
                },
                rootComponentLoaderConfig,
            ];
        case content_types_1.ContentTypes.SURVEY:
        case content_types_1.ContentTypes.EDETAILER:
            const slideLoaders = {
                test: /slides.*index\.vue$/,
                use: [
                    {
                        loader: 'template-loader',
                        options: {
                            baseDir,
                            fileProps,
                            filePathProps,
                            componentsPackageName,
                            componentType: 'slide',
                        },
                    },
                ],
            };
            return [slideLoaders, rootComponentLoaderConfig];
        case content_types_1.ContentTypes.JOURNEY:
            return [
                rootComponentLoaderConfig,
            ];
        default:
            return [];
    }
}
exports.default = default_1;
//# sourceMappingURL=get-template-loaders.js.map