"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const loader_utils_1 = require("loader-utils");
const cheerio_1 = __importDefault(require("cheerio"));
const builder_utils_1 = require("@ewizardjs/builder-utils");
const vue_template_compiler_1 = require("vue-template-compiler");
const utils_1 = require("../utils");
async function default_1(source) {
    let { baseDir, componentType, id, fileProps, filePathProps, componentsPackageName, paths } = loader_utils_1.getOptions(this);
    if (utils_1.isString(filePathProps)) {
        filePathProps = JSON.parse(filePathProps);
    }
    const moduleBaseDir = path_1.resolve(path_1.join(path_1.dirname(this.resourcePath), '..'));
    if (paths && !paths.includes(moduleBaseDir))
        return source;
    const componentId = id || path_1.basename(path_1.dirname(this.resourcePath));
    const resourcePath = utils_1.toUnixPath(this.resourcePath);
    const moduleFilePath = utils_1.toUnixPath(path_1.relative(baseDir, resourcePath));
    const moduleDir = path_1.dirname(moduleFilePath);
    const template = await getTemplate(resourcePath, moduleDir, fileProps, filePathProps, componentsPackageName);
    return source.replace('export default component.exports', `;component.options.template = '${template}';
    component.options.slideId = '${componentId}';
    component.options.__componentType = '${componentType}';
    component.options.resourcePath = '${moduleFilePath}';
    export default component.exports;`);
}
exports.default = default_1;
async function getTemplate(filePath, moduleDir, fileProps, filePathProps, componentsPackageName) {
    const vueFileContent = await utils_1.getNormalizedVueFileContent(filePath);
    const { template } = vue_template_compiler_1.parseComponent(vueFileContent, { deindent: true });
    if (template) {
        return setPublicPathTokenToMedia(template.content, moduleDir, fileProps, filePathProps, componentsPackageName)
            .replace(/\\/g, '\\\\')
            .replace(/`/g, '\\`')
            .replace(/'/g, "\\'")
            .replace(/\r?\n|\r/g, '')
            .replace(/>\s*</g, '><')
            .replace(/<!--(.*?)-->/g, '');
    }
}
function setPublicPathTokenToMedia(template, moduleDir, fileProps = {}, filePathProps = {}, componentsPackageName) {
    const templateWithReplacedObjects = builder_utils_1.replaceObjects(template, fileProps, filePathProps, componentsPackageName, false, resolveFilePath.bind(null, moduleDir));
    const $ = cheerio_1.default.load(templateWithReplacedObjects, {
        decodeEntities: false,
        _useHtmlParser2: true,
        lowerCaseTags: false,
    });
    Object.keys(fileProps).forEach((componentName) => {
        const $tag = builder_utils_1.getCheerioTag($, componentName, componentsPackageName);
        $tag === null || $tag === void 0 ? void 0 : $tag.each((i, elem) => {
            builder_utils_1.getFilePropsForElement(elem, fileProps, componentsPackageName).forEach((prop) => {
                const currentValue = $(elem).attr(prop);
                if (currentValue === 'undefined') {
                    $(elem).attr(prop, '');
                }
                else if (currentValue && !isAbsoluteUrl(currentValue)) {
                    $(elem).attr(prop, `{publicPath}${resolveFilePath(moduleDir, utils_1.encodeFilePath(currentValue))}`);
                }
                const boundPropValue = $(elem).attr(`:${prop}`);
                if (boundPropValue && boundPropValue.startsWith("'") && !boundPropValue.includes('{publicPath}')) {
                    const matched = boundPropValue.match(/'(.+?)'/);
                    const url = matched && matched[1];
                    if (url && !isAbsoluteUrl(url)) {
                        $(elem).attr(prop, `{publicPath}${resolveFilePath(moduleDir, utils_1.encodeFilePath(url))}`);
                    }
                }
            });
        });
    });
    const mediaAttrs = ['src', 'poster', 'href', 'xlink:href'];
    $('video,source,img,image,use').each((i, elem) => {
        Object.entries(elem.attribs).forEach(([attr, value]) => {
            if (mediaAttrs.includes(attr)) {
                $(elem).attr(attr, `{publicPath}${resolveFilePath(moduleDir, utils_1.encodeFilePath(value))}`);
            }
        });
    });
    return $.html();
}
function resolveFilePath(moduleDir, value) {
    if (value.includes(moduleDir)) {
        return value;
    }
    return utils_1.toUnixPath(path_1.join(moduleDir, value));
}
function isAbsoluteUrl(url) {
    return /^https?:/.test(url);
}
//# sourceMappingURL=template-loader.js.map