"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getIcon = void 0;
const fs_extra_1 = require("fs-extra");
const path_1 = require("path");
const ICON_FILE_NAME_PATTERN = /icon.*(png|jpe?g)$/i;
async function getIcon(component, options) {
    if (isBlockType(options) || isCollectOfIconsInComponent(component)) {
        const { iconDirPath, dirContent } = await getIconData(component, options);
        return collectIcons(iconDirPath, dirContent);
    }
    if (typeof component.icon === 'string') {
        const { dirContent } = await getIconData(component, options);
        return dirContent.includes(getStingBeforeLastSlash(component.icon)) ? component.icon : '';
    }
    if (typeof component.icon === 'object') {
        const existIcons = await asyncFilter(Object.entries(component.icon), async ([icon, iconPath]) => {
            const { dirContent } = await getIconData({ icon: iconPath, id: 'icon' }, options);
            return dirContent.includes(getStingBeforeLastSlash(iconPath));
        });
        return Object.fromEntries(existIcons);
    }
    return '';
}
exports.getIcon = getIcon;
const asyncFilter = async (arr, predicate) => {
    const results = await Promise.all(arr.map(predicate));
    return arr.filter((_v, index) => results[index]);
};
async function getIconData(component, options) {
    let iconDirPath = getDirPath(component.iconsPath || component.icon || component.path || path_1.join(options.blocksPath, component.id));
    const dirContent = await fs_extra_1.readdir(path_1.resolve(options.presentationPath, iconDirPath));
    return { iconDirPath, dirContent };
}
function isCollectOfIconsInComponent(component) {
    return component.iconsPath || !component.icon && component.path;
}
function getStingBeforeLastSlash(string) {
    return string.replace(/^(.*[\\\/])/, '');
}
function isBlockType(options) {
    return options.type === 'block';
}
function getDirPath(path = '') {
    return path_1.extname(path) ? path_1.dirname(path) : path;
}
function collectIcons(path, content) {
    return content
        .reduce((accumulator, file) => {
        if (ICON_FILE_NAME_PATTERN.test(file)) {
            const iconName = path_1.basename(file, path_1.extname(file));
            const iconPath = path_1.join(path, file);
            return Object.assign(Object.assign({}, accumulator), { [iconName]: iconPath });
        }
        return accumulator;
    }, {});
}
//# sourceMappingURL=utils.js.map