"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Builder = void 0;
const webpack_1 = __importDefault(require("webpack"));
const path_1 = require("path");
const builder_utils_1 = require("@ewizardjs/builder-utils");
const webpack_config_1 = __importDefault(require("../templates/webpack.config"));
const webpack_config_2 = __importDefault(require("../layout/webpack.config"));
class Builder {
    constructor(presentationPath) {
        this.options = {
            presentationPath,
            destinationPath: presentationPath,
        };
    }
    getDevConfig(options) {
        const strategiesPath = path_1.resolve(__dirname, '..', 'strategies');
        return builder_utils_1.getConfig(strategiesPath, Object.assign(Object.assign({}, this.options), options));
    }
    async getTemplatesConfig(options) {
        const devConfig = await this.getDevConfig(options);
        return webpack_config_1.default(this.options.presentationPath, devConfig);
    }
    async getLayoutConfig(options) {
        const devConfig = await this.getDevConfig(options);
        return webpack_config_2.default(this.options.presentationPath, devConfig, options);
    }
    async getCompiler(options) {
        if (options.layout) {
            const layoutConfig = await this.getLayoutConfig(options);
            return webpack_1.default(layoutConfig);
        }
        if (options.template) {
            const config = await Promise.all([
                this.getTemplatesConfig(Object.assign(Object.assign({}, options), { validate: false })),
                this.getDevConfig(options),
            ]);
            return webpack_1.default(config);
        }
        const config = await this.getDevConfig(options);
        return webpack_1.default(config);
    }
}
exports.Builder = Builder;
//# sourceMappingURL=builder.js.map