"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const alias_resolver_1 = require("@ewizardjs/alias-resolver");
const builder_utils_1 = require("@ewizardjs/builder-utils");
const aliases_1 = require("@ewizardjs/builder-utils/aliases");
const plugins_1 = require("@ewizardjs/builder-utils/plugins");
const rules_1 = require("@ewizardjs/builder-utils/rules");
const fs_extra_1 = require("fs-extra");
const path_1 = require("path");
const ramda_1 = require("ramda");
const webpack_merge_1 = require("webpack-merge");
const index_1 = require("../../enums/index");
const get_config_loaders_1 = __importDefault(require("../../get-config-loaders"));
const get_manifest_loaders_1 = __importDefault(require("../../get-manifest-loaders"));
const get_plugins_loaders_1 = __importDefault(require("../../get-plugins-loaders"));
const get_style_loaders_1 = __importDefault(require("../../get-style-loaders"));
const get_template_loaders_1 = __importDefault(require("../../get-template-loaders"));
const plugins_2 = require("../../plugins");
async function default_1(options) {
    const { presentationPath, systemSettings, target, componentsProps, currentTheme, validate, } = options;
    const blocksDir = ramda_1.pathOr('', ['path', 'blocks'], systemSettings);
    const localBlocksDir = ramda_1.pathOr('', ['path', 'localBlocks'], systemSettings);
    const localBlocksPath = path_1.resolve(presentationPath, localBlocksDir);
    const libraryBlocksPath = path_1.resolve(presentationPath, blocksDir);
    const masterTemplatePath = ramda_1.pathOr('', ['path', 'masterTemplatePath'], systemSettings);
    await Promise.all([fs_extra_1.mkdirp(localBlocksPath), fs_extra_1.mkdirp(libraryBlocksPath)]);
    const layoutOptions = {
        masterTemplatePath,
        layoutsDir: ramda_1.pathOr('', ['path', 'layouts'], systemSettings),
        layoutName: ramda_1.pathOr('', ['path', 'masterTemplateLayout'], systemSettings),
    };
    const builderPath = path_1.resolve(__dirname, '../../../');
    const webpackDevLoaders = await builder_utils_1.getWebpackDevRules(presentationPath);
    const commonPlugins = [
        new plugins_2.InjectEwizardjsAttributePlugin(presentationPath),
        plugins_1.fallbackResource(),
        plugins_1.vueLoader(),
        plugins_1.slideThumbReplacement(systemSettings),
        await plugins_2.defineDevSettings(options, systemSettings),
        await plugins_1.bannerForAssets({ include: /js$/ }, builderPath, presentationPath, 'ewizardjs'),
        new plugins_1.ValidateContentPathsPlugin(presentationPath),
    ];
    const devConfig = {
        mode: 'development',
        context: presentationPath,
        optimization: {},
        devtool: false,
        output: {
            path: presentationPath,
        },
        resolveLoader: {
            modules: [path_1.join(__dirname, '../../loaders'), ...(module.paths || [])],
        },
        resolve: {
            extensions: ['.webpack.js', '.web.js', '.ts', '.tsx', '.js'],
            alias: aliases_1.getAliases(presentationPath),
            modules: ['node_modules', path_1.resolve(presentationPath, 'node_modules')],
            symlinks: false,
            plugins: [new alias_resolver_1.DynamicAliasResolvePlugin(presentationPath, layoutOptions)],
        },
        module: {
            rules: [
                ...(await get_template_loaders_1.default(systemSettings, presentationPath, componentsProps)),
                ...(await get_style_loaders_1.default(systemSettings, presentationPath)),
                ...get_plugins_loaders_1.default(ramda_1.pathOr({}, ['plugins'], systemSettings), options),
                ...get_config_loaders_1.default(),
                ...(await get_manifest_loaders_1.default(systemSettings, presentationPath, componentsProps, currentTheme, layoutOptions)),
            ],
        },
        plugins: target === index_1.Target.Ewizard
            ? [...commonPlugins]
            : [plugins_1.progressBar(), plugins_2.statsLog(), ...commonPlugins],
    };
    if (options.target !== index_1.Target.Ewizard) {
        webpackDevLoaders.module.rules.push(rules_1.validation({ validateHtml: validate }));
        devConfig.optimization = {
            minimize: true,
            minimizer: [plugins_2.getJsMinimizer()],
        };
    }
    else {
        webpackDevLoaders.cache = {
            type: 'filesystem',
            cacheDirectory: path_1.resolve(presentationPath, 'node_modules/.cache/webpack'),
        };
    }
    if (options.debug) {
        devConfig.devtool = 'eval-source-map';
        devConfig.optimization = Object.assign(Object.assign({}, (devConfig.optimization)), { minimize: false });
    }
    return webpack_merge_1.merge(devConfig, webpackDevLoaders);
}
exports.default = default_1;
//# sourceMappingURL=webpack.config.js.map