"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const builder_utils_1 = require("@ewizardjs/builder-utils");
const rules_1 = require("@ewizardjs/builder-utils/rules");
const content_types_1 = require("@ewizardjs/content-types");
const settings_1 = require("@ewizardjs/settings");
const upath_1 = require("upath");
const webpack_merge_1 = require("webpack-merge");
const get_entry_common_loader_1 = __importDefault(require("../../get-entry-common-loader"));
const content_type_loader_1 = require("../../loaders/content-type-loader");
const plugins_1 = require("../../plugins");
const rules_2 = require("../../rules");
const webpack_config_1 = require("../../templates/webpack.config");
const webpack_config_2 = require("../../components/webpack.config");
const webpack_config_3 = __importDefault(require("../bubbles/webpack.config"));
exports.default = async (options) => {
    const baseConfig = await webpack_config_3.default(options);
    const { presentationPath, systemSettings, currentTheme: currentThemeName = await settings_1.getCurrentTheme(presentationPath), } = options;
    const { type: contentType } = systemSettings.content;
    const isModule = contentType === content_types_1.ContentTypes.MODULE;
    const isNotEdetailer = contentType !== content_types_1.ContentTypes.EDETAILER;
    const isBlocksListNeeded = isNotEdetailer && !options.layout;
    const themesList = isBlocksListNeeded
        ? await builder_utils_1.getThemesList(presentationPath, systemSettings.path.themesManifest, systemSettings.path.themes)
        : [];
    const currentBlocksList = isBlocksListNeeded
        ? builder_utils_1.getCurrentBlocks(presentationPath, systemSettings)
        : [];
    const uniqueBlocksList = isBlocksListNeeded && await builder_utils_1.containsDynamicBlocksLoader(presentationPath, systemSettings.path.rootComponent)
        ? currentBlocksList
        : [];
    const cleanPatterns = [upath_1.join(presentationPath, 'build/dev/**/*')];
    options.template && cleanPatterns.push(`!${upath_1.join(presentationPath, webpack_config_1.filename)}`);
    isModule && cleanPatterns.push(`!${upath_1.join(presentationPath, webpack_config_2.filename)}`);
    const cornConfig = {
        entry: {
            app: [require.resolve('../../../assets/entry-common'), options.appEntryPath],
            index: options.indexEntryPath,
            editor: require.resolve('../../../assets/entry-editor'),
        },
        optimization: {
            splitChunks: {
                hidePathInfo: true,
                cacheGroups: {
                    common: {
                        name: 'common',
                        chunks: 'all',
                        minSize: 1310720,
                        maxSize: 5242880,
                        minChunks: 2,
                    },
                },
            },
        },
        module: {
            rules: [
                ...content_type_loader_1.getContentTypeLoader({
                    include: /node_modules/,
                }),
                get_entry_common_loader_1.default(presentationPath),
                rules_1.currentTheme({
                    options: {
                        currentTheme: currentThemeName,
                        themes: themesList,
                    },
                }),
                rules_1.currentBlocks({
                    options: {
                        blocksList: uniqueBlocksList,
                    },
                }),
                rules_2.entryEditor({
                    options: {
                        blocksList: currentBlocksList,
                    },
                }),
            ],
        },
        output: {
            library: ['Content', '[name]'],
            jsonpFunction: 'ewizardjsJsonp',
        },
        externals: {
            './app': {
                commonjs: ['Content', 'app'],
                commonjs2: ['Content', 'app'],
                root: ['Content', 'app'],
            },
        },
        plugins: [
            new plugins_1.ResetStatePlugin(presentationPath),
            new plugins_1.InjectCommonChunksPlugin(presentationPath),
            plugins_1.cleanDestinationFolder(cleanPatterns),
        ],
    };
    return webpack_merge_1.mergeWithCustomize({
        customizeArray: webpack_merge_1.customizeArray({
            'output.library': 'replace',
            'module.rules': 'prepend',
        }),
        customizeObject: webpack_merge_1.customizeObject({
            entry: 'replace',
            externals: 'replace',
        }),
    })(baseConfig, cornConfig);
};
//# sourceMappingURL=webpack.config.js.map