"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.filename = void 0;
const cleanDestinationFolder_1 = require("../plugins/cleanDestinationFolder");
const upath_1 = require("upath");
const webpack_merge_1 = require("webpack-merge");
const PLUGINS_TO_REMOVE = [
    'CleanWebpackPlugin',
    'ValidateContentPathsPlugin',
];
exports.filename = 'build/dev/templates.js';
exports.default = (presentationPath, config) => {
    const templatesConfig = getTemplatesConfig(presentationPath);
    return webpack_merge_1.mergeWithCustomize({
        customizeArray(item1, item2, key) {
            if (key === 'plugins') {
                const defaultPlugins = item1;
                const templatesPlugins = item2;
                return removePlugins(defaultPlugins).concat(templatesPlugins);
            }
        },
    })(config, templatesConfig);
};
function getTemplatesConfig(presentationPath) {
    return {
        entry: require.resolve('../../assets/entry-templates.js'),
        mode: 'production',
        devtool: false,
        output: {
            filename: exports.filename,
            library: 'Templates',
            libraryTarget: 'window',
        },
        performance: {
            hints: false,
        },
        plugins: [
            cleanDestinationFolder_1.cleanDestinationFolder([upath_1.join(presentationPath, exports.filename)]),
        ],
    };
}
function removePlugins(plugins = []) {
    return plugins.filter(plugin => plugin.constructor && !PLUGINS_TO_REMOVE.includes(plugin.constructor.name));
}
//# sourceMappingURL=webpack.config.js.map